Welcome to gblackboard's documentation!
======================================

.. include:: ../README.rst


Contents:
---------

.. toctree::
   :maxdepth: 3
   :caption: GBlackboard

   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
